# Changelog

<!--next-version-placeholder-->

## v0.2.0 (2022-08-22)
### Feature
* Support 'str_pattern' to filter valid path ([`2a3e2c4`](https://github.com/haoxiangsnr/audioinfo/commit/2a3e2c4dd26ab2224371ea5eeee60e2bc89bb8d0))

## v0.1.7 (2022-08-12)
### Fix
* Wrong logic in the bool arguments ([`bb0dba1`](https://github.com/haoxiangsnr/audioinfo/commit/bb0dba1e369ffc1ae8272a06c831951177e31da8))

## v0.1.6 (2022-08-10)
### Fix
* Unify the float format to two decimals ([`d970f3a`](https://github.com/haoxiangsnr/audioinfo/commit/d970f3a4c6e0c95ec84f0ebcc0ab12bf5eb22508))

## v0.1.5 (2022-08-10)
### Fix
* Wrong format of duration ([`f2762a0`](https://github.com/haoxiangsnr/audioinfo/commit/f2762a06e135c18ad33d2aa52a8d3de043217c06))

## v0.1.4 (2022-08-10)
### Fix
* Test build ([`3ac8dc4`](https://github.com/haoxiangsnr/audioinfo/commit/3ac8dc4a2995db672a0d5b8a533ec113f54cfaaf))

## v0.1.3 (2022-08-10)
### Fix
* Remove doc build ([`be99020`](https://github.com/haoxiangsnr/audioinfo/commit/be99020939ecc405e240669c384d9a9c5868dec8))

## v0.1.2 (2022-08-10)
### Fix
* Add default options ([`9921311`](https://github.com/haoxiangsnr/audioinfo/commit/9921311221e7767926ae9edf5ed6d29d0e824139))

## v0.1.1 (2022-08-10)
### Fix
* Wrong release version ([`3acaab8`](https://github.com/haoxiangsnr/audioinfo/commit/3acaab87631e7b12a4cd887d74daee84a305e6b2))
* Lower version ([`a92fda3`](https://github.com/haoxiangsnr/audioinfo/commit/a92fda3b930de43f2d2231b0169a7a6821768a7e))

## v0.1.0 (2022-08-10)
### Feature
* Initial audioinfo ([`78816b7`](https://github.com/haoxiangsnr/audioinfo/commit/78816b72eb4a00ca1ded67be2dcec522f064f96e))